==> open-xchange-usm_6.22.0.orig.tar.bz2: open-xchange-usm-6.22.0/com.openexchange.usm.session.impl/src/com/openexchange/usm/session/impl/USMSessionInformationMBean.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2010 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */
package com.openexchange.usm.session.impl;

public interface USMSessionInformationMBean {

	String CACHE_DOMAIN = "com.openexchange.usm.session";

	int getActiveSessionCount();

	int getWaitForChangesEmailPullDelay();

	void setWaitForChangesEmailPullDelay(int value);

	int getWaitForChangesEmailMinPullDelay();

	void setWaitForChangesEmailMinPullDelay(int value);

	int getMaxSyncStatesInDB();

	void setMaxSyncStatesInDB(int states);

	boolean getKeepLastSentSyncStateInDB();

	void setKeepLastSentSyncStateInDB(boolean set);

	String[] listActiveSessions();

	String[] getPropertiesOfActiveSessions(int cid, int id, String user, String protocol, String device, String field);

	String updatePropertiesOfActiveSessions(int cid, int id, String user, String protocol, String device, String field,
			String value);

	String[] getPropertiesOfAllSessions(int cid, int id, String protocol, String device, String field);

	String[] updatePropertiesOfAllSessions(int cid, int id, String protocol, String device, String field, String value);
}

==> open-xchange-usm_7.2.2.orig.tar.bz2: open-xchange-usm-7.2.2/com.openexchange.usm.session.impl/src/com/openexchange/usm/session/impl/USMSessionInformationMBean.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2010 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.usm.session.impl;

public interface USMSessionInformationMBean {

    String SESSION_DOMAIN = "com.openexchange.usm.session";

    int getActiveSessionCount();

    int getWaitForChangesEmailPullDelay();

    void setWaitForChangesEmailPullDelay(int value);

    int getWaitForChangesEmailMinPullDelay();

    void setWaitForChangesEmailMinPullDelay(int value);

    int getMaxSyncStatesInDB();

    void setMaxSyncStatesInDB(int states);

    boolean getKeepLastSentSyncStateInDB();

    void setKeepLastSentSyncStateInDB(boolean set);

    String[] listActiveSessions();

    String[] getPropertiesOfActiveSessions(int cid, int id, String user, String protocol, String device, String field);

    String updatePropertiesOfActiveSessions(int cid, int id, String user, String protocol, String device, String field, String value);

    String[] getPropertiesOfAllSessions(int cid, int id, String protocol, String device, String field);

    String[] updatePropertiesOfAllSessions(int cid, int id, String protocol, String device, String field, String value);

    int getUSMSesssionCacheInactivityTimeout();

    void setUSMSesssionCacheInactivityTimeout(int timeout);

    int getSyncStateCacheInactivityTimeout();

    void setSyncStateCacheInactivityTimeout(int timeout);

    int getTotalUSMSessionsInMemory();

    int getTotalSyncStatesInMemory();

    void clearCacheCounters();

    int getNewUSMSessionsInMemory();

    int getUSMSessionsRemovedDueToInactivity();

    int getUSMSessionsRemovedByJVM();

    int getSyncStatesSavedToDatabase();

    int getSyncStatesLoadedFromDatabase();

    int getSyncStatesRemovedDueToInactivity();
}
